<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>BasicEdit</name>
    <message>
        <source>Line: </source>
        <translation>Lijn: </translation>
    </message>
    <message>
        <source>New Program?</source>
        <translation>Nieuw Programma?</translation>
    </message>
    <message>
        <source>Are you sure you want to completely clear this program and start a new one?</source>
        <translation>Wilt u dit echt programma wissen en een nieuwe beginnen?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Ja</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Annuleren</translation>
    </message>
    <message>
        <source>Untitled - BASIC-256</source>
        <translation>Naamloos - BASIC-256</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Bestand opslaan als</translation>
    </message>
    <message>
        <source>BASIC-256 File </source>
        <translation>BASIC-256 Bestand </translation>
    </message>
    <message>
        <source>Any File </source>
        <translation>Alle Bestanden </translation>
    </message>
    <message>
        <source> - BASIC-256</source>
        <translation> - BASIC-256</translation>
    </message>
    <message>
        <source>Open a file</source>
        <translation>Open een bestand</translation>
    </message>
    <message>
        <source>BASIC-256 file </source>
        <translation>BASIC-256 bestand </translation>
    </message>
    <message>
        <source> Column: </source>
        <translation>Kolom:</translation>
    </message>
    <message>
        <source>The file </source>
        <translation>Het bestand </translation>
    </message>
    <message>
        <source> already exists.</source>
        <translation> bestaat reeds.</translation>
    </message>
    <message>
        <source>Do you want to overwrite?</source>
        <translation>Wilt u dit bestand overschrijven?</translation>
    </message>
    <message>
        <source>Program modifications have not been saved.</source>
        <translation>Aanpassingen werden niet bewaard.</translation>
    </message>
    <message>
        <source>Do you want to discard your changes?</source>
        <translation>Wilt u de aanpassingen negeren?</translation>
    </message>
    <message>
        <source>String not found.</source>
        <translation>String niet gevonden.</translation>
    </message>
    <message>
        <source>Replace completed.</source>
        <translation>Vervanging uitgevoerd.</translation>
    </message>
</context>
<context>
    <name>DocumentationWin</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Terug</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vooruit</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Begin</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>Af&amp;sluiten</translation>
    </message>
</context>
<context>
    <name>FindWin</name>
    <message>
        <source>BASIC-256 Find</source>
        <translation>BASIC-256 Zoeken</translation>
    </message>
    <message>
        <source>Search For:</source>
        <translation>Zoek naar:</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <source>Search Backwards</source>
        <translation>Zoek naar Boven</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Zoek</translation>
    </message>
</context>
<context>
    <name>Interpreter</name>
    <message>
        <source>ERROR on line </source>
        <translation>FOUT op lijn </translation>
    </message>
    <message>
        <source>Syntax error on line </source>
        <translation>Syntax fout op lijn </translation>
    </message>
    <message>
        <source>No such label</source>
        <translation type="obsolete">Geen label met die naam</translation>
    </message>
    <message>
        <source>Next without FOR</source>
        <translation type="obsolete">NEXT zonder FOR</translation>
    </message>
    <message>
        <source>Array dimension too large</source>
        <translation type="obsolete">Array te groot</translation>
    </message>
    <message>
        <source>Cannot assign non-string to string array</source>
        <translation type="obsolete">Kan niet-string niet aan string array toewijzen</translation>
    </message>
    <message>
        <source>Array index out of bounds</source>
        <translation type="obsolete">Array index buiten grens</translation>
    </message>
    <message>
        <source>Cannot access non-array variable</source>
        <translation type="obsolete">Geen toegang tot niet-array variabele</translation>
    </message>
    <message>
        <source>Unknown variable</source>
        <translation type="obsolete">Onbekende variabele</translation>
    </message>
    <message>
        <source>Illegal argument to int()</source>
        <translation type="obsolete">Illegaal argument voor int()</translation>
    </message>
    <message>
        <source>Illegal argument to string()</source>
        <translation type="obsolete">Illegaal argument voor string()</translation>
    </message>
    <message>
        <source>Illegal argument to sin()</source>
        <translation type="obsolete">Illegaal argument voor sin()</translation>
    </message>
    <message>
        <source>Illegal argument to cos()</source>
        <translation type="obsolete">Illegaal argument voor cos()</translation>
    </message>
    <message>
        <source>Illegal argument to tan()</source>
        <translation type="obsolete">Illegaal argument voor tan()</translation>
    </message>
    <message>
        <source>Illegal argument to ceil()</source>
        <translation type="obsolete">Illegaal argument voor ceil()</translation>
    </message>
    <message>
        <source>Illegal argument to floor()</source>
        <translation type="obsolete">Illegaal argument voor floor()</translation>
    </message>
    <message>
        <source>Illegal argument to abs()</source>
        <translation type="obsolete">Illegaal argument voor abs()</translation>
    </message>
    <message>
        <source>String in numeric expression</source>
        <translation type="obsolete">String in numerieke uitdrukking</translation>
    </message>
    <message>
        <source>Cannot compare strings with &gt; or &lt;=</source>
        <translation type="obsolete">Kan strings niet met &gt; of &lt; verglijken</translation>
    </message>
    <message>
        <source>Cannot compare strings with &lt; or &gt;=</source>
        <translation type="obsolete">Kan strings niet met &lt; of &gt; verglijken</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="obsolete">Kan bestand niet openen</translation>
    </message>
    <message>
        <source>Illegal argument to open()</source>
        <translation type="obsolete">Illegaal argument voor open()</translation>
    </message>
    <message>
        <source>Can&apos;t read -- no open file.</source>
        <translation type="obsolete">Lezen nicht mogelijk -- geen open bestand.</translation>
    </message>
    <message>
        <source>Unable to write to file</source>
        <translation type="obsolete">Kan niet in bestand schrijven</translation>
    </message>
    <message>
        <source>Illegal argument to write()</source>
        <translation type="obsolete">Illegaal argument voor write()</translation>
    </message>
    <message>
        <source>Illegal argument to length()</source>
        <translation type="obsolete">Illegaal argument voor length()</translation>
    </message>
    <message>
        <source>Illegal argument to poly()</source>
        <translation type="obsolete">Illegaal argument voor poly()</translation>
    </message>
    <message>
        <source>Not enough points in array for poly()</source>
        <translation type="obsolete">Niet genoeg punten in array voor poly()</translation>
    </message>
    <message>
        <source>reset() called when no file is open</source>
        <translation type="obsolete">reset() gebruikt -- maar er is geen bestand open</translation>
    </message>
    <message>
        <source>Unable to reset file</source>
        <translation type="obsolete">reset() niet mogelijk</translation>
    </message>
    <message>
        <source>Illegal argument to mid()</source>
        <translation type="obsolete">Illegaal argument voor mid()</translation>
    </message>
    <message>
        <source>String not long enough for given starting character</source>
        <translation type="obsolete">String niet lang genoeg voor het gegeven karakter</translation>
    </message>
    <message>
        <source>Illegal argument to instr()</source>
        <translation type="obsolete">Illegaal argument voor instr()</translation>
    </message>
    <message>
        <source>Sound file must be a string.</source>
        <translation type="obsolete">Geluid bestand moet een string zijn.</translation>
    </message>
    <message>
        <source>Illegal FOR -- start number &gt; end number</source>
        <translation type="obsolete">Ongeldig FOR commando .--.start is groter dan einde</translation>
    </message>
    <message>
        <source>Illegal FOR -- start number &lt; end number</source>
        <translation type="obsolete">Ongeldig FOR commando .--.start is kleiner dan einde</translation>
    </message>
    <message>
        <source>Array dimension too small</source>
        <translation type="obsolete">Rij dimensie is te klein</translation>
    </message>
    <message>
        <source> around end of line.</source>
        <translation>ergens op het einde van de lijn</translation>
    </message>
    <message>
        <source> around column </source>
        <translation>rond kolom</translation>
    </message>
    <message>
        <source>Can&apos;t size -- no open file.</source>
        <translation type="obsolete">Kan grootte niet bepalen -- er is geen open bestand.</translation>
    </message>
    <message>
        <source>seek() called when no file is open</source>
        <translation type="obsolete">seek() opgeroepen, maar geen enkel bestand is open</translation>
    </message>
    <message>
        <source>Not a string array variable</source>
        <translation type="obsolete">Geen String Reeks Variabele</translation>
    </message>
    <message>
        <source>Not an array variable</source>
        <translation type="obsolete">Geen Reeks Variabele</translation>
    </message>
    <message>
        <source>Argument not an array for poly()</source>
        <translation type="obsolete">Argument is geen reeks voor poly()</translation>
    </message>
    <message>
        <source>Not enough points in immediate list for poly()</source>
        <translation type="obsolete">Niet genoeg punten in directe lijst voor poly() functie</translation>
    </message>
    <message>
        <source>Not enough points in array for stamp()</source>
        <translation type="obsolete">Niet genoeg punten in directe lijst voor stamp() functie</translation>
    </message>
    <message>
        <source>Argument not an array for stamp()</source>
        <translation type="obsolete">Argument is geen Reeks voor stamp() functie</translation>
    </message>
    <message>
        <source>Not enough points in immediate list for stamp()</source>
        <translation type="obsolete">Niet genoeg punten in directe lijst voor stamp() functie</translation>
    </message>
    <message>
        <source>Illegal argument</source>
        <translation type="obsolete">Ongeldig argument</translation>
    </message>
    <message>
        <source>RGB Color values must be in the range of 0 to 255.</source>
        <translation type="obsolete">RGB kleurwaarden moeten tussen 0 en 255 zijn.</translation>
    </message>
    <message>
        <source>ERROR - Unable to initialize Winsock library.
</source>
        <translation>FOUT - Winsock initialisatie gaat niet.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find inpout32.dll - direct port I/O disabled.
</source>
        <translation>Kan inpout32.dll niet vinden - direct port I/O werd afgezet.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find Inp32 in inpout32.dll - direct port I/O disabled.
</source>
        <translation>Kan inp32 in inpout32.dll niet vinden - direct port I/O werd afgezet.</translation>
    </message>
    <message>
        <source>ERROR - Unable to find Out32 in inpout32.dll - direct port I/O disabled.
</source>
        <translation>Kan Out32 in inpout32.dll niet vinden - direct port I/O werd afgezet.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Program modifications have not been saved.</source>
        <translation>Aanpassingen aan het programma werden nog niet bewaard.</translation>
    </message>
    <message>
        <source>Do you want to discard your changes?</source>
        <translation>Wil u de aanpassingen negeren?</translation>
    </message>
</context>
<context>
    <name>PreferencesWin</name>
    <message>
        <source>BASIC-256 Preferences and Settings</source>
        <translation>BASIC-256 Instellingen en Voorkeuren</translation>
    </message>
    <message>
        <source>Preferences and Settings Password:</source>
        <translation>Instellingen en Voorkeuren Paswoord:</translation>
    </message>
    <message>
        <source>Allow SYSTEM statement</source>
        <translation>Laat SYSTEM opdracht toe</translation>
    </message>
    <message>
        <source>Allow GETSETTING/SETSETTING statements</source>
        <translation>Laat GESTSETTING/SETSETTING opdrachten toe</translation>
    </message>
    <message>
        <source>Allow PORTIN/PORTOUT statements</source>
        <translation>Laat PORTIN/PORTOUT opdrachten toe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Preferences and settings have been saved.</source>
        <translation>Instellingen en Voorkeuren werden bewaard.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Run</source>
        <translation type="obsolete">Uitvoeren</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="obsolete">Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Stop</translation>
    </message>
    <message>
        <source>Step</source>
        <translation type="obsolete">Stap</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Bestand</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="obsolete">Nieuw</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="obsolete">Openen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Opslaan</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="obsolete">Opslaan als</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Afsluiten</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="obsolete">Bewerken</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="obsolete">Knippen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="obsolete">Alles selecteren</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="obsolete">Extras</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">Debuggen</translation>
    </message>
    <message>
        <source>Save Compiled Byte Code</source>
        <translation type="obsolete">Bytecode opslaan</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">Over</translation>
    </message>
    <message>
        <source>About BASIC-256</source>
        <translation>Over BASIC-256</translation>
    </message>
    <message>
        <source>Graphics Output</source>
        <translation>Grafisch Venster</translation>
    </message>
    <message>
        <source>Text Output</source>
        <translation>Tekst Venster</translation>
    </message>
    <message>
        <source>Ready.</source>
        <translation>Klaar.</translation>
    </message>
    <message>
        <source>Untitled - BASIC-256</source>
        <translation>Naamloos - BASIC-256</translation>
    </message>
    <message>
        <source>Print Code</source>
        <translation>Programma afdrukken</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Print Text Output</source>
        <translation>Tekstvenster afdrukken</translation>
    </message>
    <message>
        <source>Print Graphics Output</source>
        <translation>Grafisch Venster afdrukken</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="obsolete">View</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation type="obsolete">Gereedschap</translation>
    </message>
    <message>
        <source>Main</source>
        <translation type="obsolete">Hoofdvenster</translation>
    </message>
    <message>
        <source>Print Error</source>
        <translation>Fout bij afdrukken</translation>
    </message>
    <message>
        <source>Unable to carry out printing.
Please check your printer settings.</source>
        <translation>Kan niet afdrukken.
Check uw printer instelling.</translation>
    </message>
    <message>
        <source>Text Window</source>
        <translation type="obsolete">Tekstvenster</translation>
    </message>
    <message>
        <source>Graphics Window</source>
        <translation type="obsolete">Grafikkenvenster</translation>
    </message>
    <message>
        <source>Variable Watch Window</source>
        <translation type="obsolete">Variabelenvenster</translation>
    </message>
    <message>
        <source>&lt;h2 align=&apos;center&apos;&gt;BASIC-256 -- Version 0.9.2&lt;/h2&gt; 					&lt;p&gt;Copyright &amp;copy; 2006, The BASIC-256 Team&lt;/p&gt;	                                        &lt;p&gt;Please visit our web site at http://kidbasic.sourceforge.net for tutorials and documentation.&lt;/p&gt; 					&lt;p&gt;Please see the CONTRIBUTORS file for a list of developers and translators for this project.&lt;/p&gt;				        &lt;p&gt;&lt;i&gt;You should have received a copy of the GNU General Public License along&lt;br&gt; 					with this program; if not, write to the Free Software Foundation, Inc.,&lt;br&gt; 					51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h2 align=&apos;center&apos;&gt;BASIC-256 -- Version 0.9.2&lt;/h2&gt; 	&lt;p&gt;Copyright &amp;copy; 2006, Het BASIC-256 Team&lt;/p&gt;	&lt;p&gt;Lees alstublieft het CONTRIBUTORS bestand voor een lijst van ontwikkelaars en vertalers voor dit project.&lt;/p&gt;	&lt;p&gt;&lt;i&gt;U zou een exemplaar van de GNU General Public License samen&lt;br&gt; 					met dit programma moeten ontvangen hebben; als niet, schrijf aan the Free Software Foundation, Inc.,&lt;br&gt; 					51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Openen</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Be&amp;waren</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Bewaren &amp;Als</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Af&amp;drukken</translation>
    </message>
    <message>
        <source>&amp;Exit</source>
        <translation>Af&amp;sluiten</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Aan&amp;passen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>K&amp;nippen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Alles Selecteren</translation>
    </message>
    <message>
        <source>&amp;Beautify</source>
        <translation>&amp;Maak Mooier</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Bekijken</translation>
    </message>
    <message>
        <source>&amp;Text Window</source>
        <translation>&amp;Tekst Venster</translation>
    </message>
    <message>
        <source>&amp;Graphics Window</source>
        <translation>&amp;Grafisch Venster</translation>
    </message>
    <message>
        <source>&amp;Variable Watch Window</source>
        <translation>&amp;Variabelen Verklikker Venster</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>&amp;Werkbalken</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Programma</translation>
    </message>
    <message>
        <source>&amp;Text Output</source>
        <translation>&amp;Tekst Venster</translation>
    </message>
    <message>
        <source>&amp;Graphics Output</source>
        <translation>&amp;Grafisch Venster</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>&amp;Voer Uit</translation>
    </message>
    <message>
        <source>&amp;Debug</source>
        <translation>&amp;Fouten Opsporen</translation>
    </message>
    <message>
        <source>S&amp;tep</source>
        <translation>S&amp;tap vooruit</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <source>Save Compiled &amp;Byte Code</source>
        <translation type="obsolete">Bewaar &amp;Gecomplieerde Byte Code</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">&amp;Over</translation>
    </message>
    <message>
        <source>&amp;About BASIC-256</source>
        <translation>Over &amp;BASIC-256</translation>
    </message>
    <message>
        <source>BASIC-256 Reference</source>
        <translation>BASIC-256 Referentie</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Opnieu&amp;w doen</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Vervang</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>V&amp;oorkeuren</translation>
    </message>
    <message>
        <source>&amp;Edit Window</source>
        <translation>&amp;Bewerken Venster</translation>
    </message>
    <message>
        <source>&amp;Font Size</source>
        <translation>&amp;Lettertype en grootte</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation>&amp;Klein</translation>
    </message>
    <message>
        <source>&amp;Medium</source>
        <translation>&amp;Gemiddeld</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation>G&amp;root</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation>&amp;Zeer groot</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Online Hulp</translation>
    </message>
    <message>
        <source>&lt;h2&gt;BASIC-256&lt;/h2&gt;version &lt;b&gt;</source>
        <translation>&lt;h2&gt;BASIC-256&lt;/h2&gt;versie &lt;b&gt;</translation>
    </message>
    <message>
        <source>&lt;/b&gt;&lt;p&gt;Copyright &amp;copy; 2006-2010, The BASIC-256 Team&lt;/p&gt;&lt;p&gt;Please visit our web site at &lt;a href=http://www.basic256.org&gt;basic256.org&lt;/a&gt; for tutorials and documentation.&lt;/p&gt;&lt;p&gt;Please see the CONTRIBUTORS file for a list of developers and translators for this project.&lt;/p&gt;&lt;p&gt;&lt;i&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;/b&gt;&lt;p&gt;Copyright &amp;copy; 2006-2010, Het BASIC-256 Team&lt;/p&gt;&lt;p&gt;Bezoek onze website op &lt;a href=http://www.basic256.org&gt;basic256.org&lt;/a&gt; voor handleidingen en documentatie.&lt;/p&gt;&lt;p&gt;Neem de tijd om de lijst van CONTRIBUTORS door te nemen van dit project.&lt;/p&gt;&lt;p&gt;&lt;i&gt;U zou een kopie van de GNU General Public License samen met dit programma moeten ontvangen hebben;Is dat niet het geval, dan kan u schrijven naar &apos;the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ReplaceWin</name>
    <message>
        <source>BASIC-256 Replace</source>
        <translation>BASIC-256 Vervang</translation>
    </message>
    <message>
        <source>From:</source>
        <translation>Van:</translation>
    </message>
    <message>
        <source>To:</source>
        <translation>Naar:</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>Vervang alles</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Vervang</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Zoek</translation>
    </message>
</context>
<context>
    <name>RunController</name>
    <message>
        <source>Running</source>
        <translation>Wordt Uitgevoerd</translation>
    </message>
    <message>
        <source>Ready.</source>
        <translation>Klaar.</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Bestand opslaan als</translation>
    </message>
    <message>
        <source>BASIC-256 Compiled File </source>
        <translation>Bewaar Gecomplieerde B&amp;yte Code</translation>
    </message>
    <message>
        <source>Any File </source>
        <translation>Alle bestanden </translation>
    </message>
    <message>
        <source>BASIC-256 Preferences and Settings</source>
        <translation>BASIC-256 Voorkeuren en Instellingen</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Paswoord:</translation>
    </message>
</context>
<context>
    <name>VariableWin</name>
    <message>
        <source>Variable Watch</source>
        <translation>Variabele:Opvolgen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Waarde</translation>
    </message>
    <message>
        <source>&lt;array </source>
        <translation>&lt;array </translation>
    </message>
</context>
</TS>
